capture log close
log using logfiles/encomp_scc.log, replace   
clear
clear matrix
clear mata

set more off 
set matsize 10000 
set maxvar 10100
                  


************************************************************************
*	This file uses data generated by pop_wind_dm.do 
*	and the MN10 data to run 2 encompassing tests: 
*	The role of population and wind on temp trends in Canadian cities
*	and the difference between GDP&POP levels versus changes
*	on temperatures around the world
*	
*	THIS FILE APPLIES DRISCOLL-KRAAY STD ERRORS & OTHER SAC TREATMENTS
*
************************************************************************


use data/monthlywindpop.dta					// data assembled in windpop_dm

generate tt = ym(year,month)				// time trend
tsset ncity tt
format tt %tm

generate scale=1
bysort city: egen sdwindu=sd(windu)			// compute std dev's of wind speed by city
bysort city: egen sdwindr=sd(windr)
generate duwind=windu>scale*sdwindu			// if mean windu is > scale*SD above average
generate drwind=windr>scale*sdwindr			// if mean windr is > scale*SD above average


************************************************************************
*
*		TABLE 1: SUMMARY STATS 
*
************************************************************************
tabulate city, gen(c)
tabulate month, gen(m)

*	remove city and monthly means
regress tempu c1-c9 m1-m11
	predict anom, resid
	replace tempu=anom
	drop anom
regress tempr c1-c9 m1-m11
	predict anom, resid
	replace tempr=anom
	drop anom
regress windu c1-c9 m1-m11
	predict anom, resid
	replace windu=anom
	drop anom
regress windr c1-c9 m1-m11
	predict anom, resid
	replace windr=anom
	drop anom
regress mpop c1-c9 
	predict anom, resid
	replace mpop=anom
	drop anom

format	tempu tempr windu windr mpop duwind drwind %5.3f
sum		tempu tempr windu windr mpop duwind drwind tt, format

drop c1 c2 c3 c4 c5 c6 c7 c8 c9 c10
drop m1 m2 m3 m4 m5 m6 m7 m8 m9 m10 m11 m12


************************************************************************
*
*		TABLE 2: MONTHLY TEMPERATURE TRENDS BY CDN CITY
*
************************************************************************
replace tempu=120*tempu	// put onto decadal scale
replace tempr=120*tempr
bysort city: regress tempu tt
bysort city: regress tempr tt
replace tempu=tempu/120	// put  onto monthly scale
replace tempr=tempr/120



************************************************************************
*
*		TABLE 3: REGRESSIONS ON CDN CITIES
*
************************************************************************

generate duwindt=duwind*tt
generate drwindt=drwind*tt
local sz="msiz(small small)"
local mc="mc(green blue)"

// URBAN Data
	xtscc tempu tt duwindt duwind , lag(4)			//	Urban, Wind only; no Population Var
		generate urban_calm=(_b[_cons]*_cons+_b[tt]*tt)/120 if duwind==0
		generate urban_windy=(0.9+_b[_cons]*_cons+_b[duwind]*duwind+_b[tt]*tt+_b[duwindt]*duwindt)/120 if duwind==1
		lincom tt+duwindt

	xtscc tempu tt mpop duwindt duwind , lag(4) 	// 	Urban, Wind + Population
		generate urban2_calm=(_b[_cons]*_cons+_b[tt]*tt)/120 if duwind==0
		generate urban2_windy=(.9+_b[_cons]*_cons+_b[duwind]*duwind+_b[tt]*tt+_b[duwindt]*duwindt)/120 if duwind==1
		lincom tt+duwindt

	label var urban_calm "Urban temperatures on calm nights"
	label var urban_windy "Urban temperatures on windy nights"
	
	label var urban2_calm "Urban temperatures on calm nights"
	label var urban2_windy "Urban temperatures on windy nights"

	scatter urban_calm urban_windy tt , `mc' `sz' xtitle("Date") ///
		ytitle("deg C") ylabel(-0.01(.01).01) 	// graph w/o pop control
		graph save graphs/urban.gph, replace
	scatter urban2_calm urban2_windy tt , `mc' `sz' xtitle("Date") ///
		ytitle("deg C") ylabel(-0.01(.01).01)	// graph with pop control
		graph save graphs/urban2.gph, replace

		


// REMOTE Data
	xtscc tempr tt drwindt drwind , lag(4) 			//	Rural, Wind only; no Population Var
		generate rural_calm=(_b[_cons]*_cons+_b[tt]*tt)/120 if duwind==0
		generate rural_windy=(0.3+_b[_cons]*_cons+_b[drwind]*drwind+_b[tt]*tt+_b[drwindt]*drwindt)/120 if drwind==1
		lincom tt+drwindt

	xtscc tempr tt mpop drwindt drwind , lag(4)		// Rural, Wind + Population
		generate rural2_calm=(_b[_cons]*_cons+_b[tt]*tt)/120 if duwind==0
		generate rural2_windy=(.2+_b[_cons]*_cons+_b[drwind]*drwind+_b[tt]*tt+_b[drwindt]*drwindt)/120 if drwind==1
		lincom tt+drwindt

	label var rural_calm "Rural temperatures on calm nights"
	label var rural_windy "Rural temperatures on windy nights"
	label var rural2_calm "Rural temperatures on calm nights"
	label var rural2_windy "Rural temperatures on windy nights"

	scatter rural_calm rural_windy tt , `mc' `sz' xtitle("Date") ///
		ytitle("deg C") ylabel(-0.01(.01).01)	// graph w/o pop control
		graph save graphs/rural.gph, replace
	scatter rural2_calm rural2_windy tt , `mc' `sz' xtitle("Date") ///
		ytitle("deg C") ylabel(-0.01(.01).01)	// graph with pop control
		graph save graphs/rural2.gph, replace


graph combine graphs/urban.gph graphs/rural.gph , cols(1) 
	graph save graphs/Fig1, replace
	graph export graphs/Fig1.eps, replace
graph combine graphs/urban2.gph graphs/rural2.gph , cols(1)
	graph save graphs/Fig2, replace
	graph export graphs/Fig2.eps, replace



***********************************************************************************
*
*	MN-10 ANALYSIS: STATIC SAMPLE SPLIT VS CHANGE ON CHANGE TERMS
*
***********************************************************************************


clear
use data/mn10data.dta
drop if cru3v==.

sum(cru3v uah4 slp dry water abslat g e x p m y c) [w=gcs]

egen mean_g=mean(g)
egen std_g=sd(g)
generate hi_g=(g>(mean_g+std_g))

//                GENERATE Row-Standardized MATRIX AND EIGENVALUES FOR REG COMMANDS
spatwmat using data/Wmat_428_27.dta   , name(W27) eigenval(E27) standardize		// CRU3v-UAH4

//	QUIETLY GET NON-SAC RESULTS BACK
qui regress cru3v uah4 slp dry dslp water abslat g e x p m y c ,robust cluster(gdp99)
	est store c3vu4					

	
	
//		NOW DO SAC TESTING ON CRU3v AND UAH4
qui regress cru3v uah4 slp dry dslp water abslat g e x p m y c 
	spatdiag, weights(W27)



spatreg cru3v g, weights(W27) eigenval(E27) model(lag) robust

spatreg cru3v uah4 slp dry dslp water abslat g e x p m y c , weights(W27) eigenval(E27) model(lag) robust
	est store all
	matrix b=e(b)
	predict fitc3u4

	mkmat cru3v, matrix(y)				// reconstruct fitted values using lagged depvars
	matrix lagy=b[1,15]*W27*y
	svmat lagy
	generate fitc3u4_l=fitc3u4+lagy1

										// do filtering on trend vector
	generate clim_c3u4=_b[_cons]+_b[uah4]*uah4+_b[slp]*slp+_b[dry]*dry+_b[dslp]*dslp+_b[water]*water+_b[abslat]*abslat+_b[g]*.36762+_b[e]*144.2+lagy1
	sum cru3v fitc3u4_l clim_c3u4
	drop lagy1
	matrix drop b lagy

	test g e                             		    // Inhomogeneity
	test p m y c                                  	// Surface processes
	test g e p m y c                             	// All 
	test uah4 slp dry dslp water abslat e x p m y c

est table all, b(%9.3f) t(%9.3f) 
	
exit
